# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AzureCloudRegion(Enum):
    US_WEST = "US_WEST"
    US_WEST2 = "US_WEST2"
    US_CENTRAL = "US_CENTRAL"
    US_EAST = "US_EAST"
    US_EAST2 = "US_EAST2"
    US_NORTH_CENTRAL = "US_NORTH_CENTRAL"
    US_SOUTH_CENTRAL = "US_SOUTH_CENTRAL"
    US_WEST_CENTRAL = "US_WEST_CENTRAL"
    CANADA_CENTRAL = "CANADA_CENTRAL"
    CANADA_EAST = "CANADA_EAST"
    BRAZIL_SOUTH = "BRAZIL_SOUTH"
    EUROPE_NORTH = "EUROPE_NORTH"
    EUROPE_WEST = "EUROPE_WEST"
    UK_SOUTH = "UK_SOUTH"
    UK_WEST = "UK_WEST"
    ASIA_EAST = "ASIA_EAST"
    ASIA_SOUTHEAST = "ASIA_SOUTHEAST"
    JAPAN_EAST = "JAPAN_EAST"
    JAPAN_WEST = "JAPAN_WEST"
    AUSTRALIA_EAST = "AUSTRALIA_EAST"
    AUSTRALIA_SOUTHEAST = "AUSTRALIA_SOUTHEAST"
    INDIA_CENTRAL = "INDIA_CENTRAL"
    INDIA_SOUTH = "INDIA_SOUTH"
    INDIA_WEST = "INDIA_WEST"
    KOREA_CENTRAL = "KOREA_CENTRAL"
    KOREA_SOUTH = "KOREA_SOUTH"
    CHINA_NORTH = "CHINA_NORTH"
    CHINA_EAST = "CHINA_EAST"
    GERMANY_CENTRAL = "GERMANY_CENTRAL"
    GERMANY_NORTHEAST = "GERMANY_NORTHEAST"
    GOV_US_VIRGINIA = "GOV_US_VIRGINIA"
    GOV_US_IOWA = "GOV_US_IOWA"
